| runSymbolicAnalysis | R Documentation |
Provide alternative methods to handle the sparse linear algebra required by TMB.
runSymbolicAnalysis(obj, method = c("CHOLMOD", "incomplete"), ...)
obj |
Output from |
method |
Which method to use; see details. |
... |
Extra paramters depending on the method. |
method="CHOLMOD"
Aggressively tries to reduce fill-in of sparse Cholesky factor by
running a full suite of ordering algorithms. NOTE: requires a
specialized installation of the package. More information is
available at the package URL. This method is mainly for backward compatibility and dates back to before the Matrix package included the mentioned ordering algorithms.
method="incomplete"
This experimental method determines an approximate factorization of the form H=L D L^T where small elements of L are dropped. It supports a number of extra arguments:
tol Drop elements with abs(L)<tol recursively while calculating new rows of L.
abstol, maxit Linear systems H x = y are solved using iterative refinement with absolute error tolerance abstol and maximum number of iterations maxit.
trace Method specific output can be enabled by trace=TRUE.
perm Specifies the elimination order; Natural order by default.
adaptive TRUE by default; Redo symbolic analysis gradually if the incomplete factor becomes inaccurate (error > tol * relax).
parallel FALSE by default; Run incomplete factorization and its adjoint code using OpenMP. This option normally requires an elimination order (perm) to provide speedups.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.